Overview - VoDEx Docs

This part of the project documentation is a reference for the technical implementation of the `VoDEx` project code.

# vodex.loaders module

This module contains classes to load and collect information from the imaging data.

The module contains the following classes:

- `TiffLoader` - A class to work with tiff image files. It is used to get the datatype of the images, get the number of frames in each tiff file and load frames from tiff files. You can create your own loaders to work with other file types.

- `ImageLoader` - Chooses appropriate loader based on the type of the imaging files, collects information about the datatype, number of frames per file and loads data from files.

# vodex.core module

This module contains classes to specify the information about the imaging data, about the experimental conditions and load the data based on the specified information.

The module contains the following classes:

- `FileManager` - Figures out stuff concerning the many files. For example in what order do stacks go? Will grab all the files with the provided file_extension in the provided folder and order them alphabetically.

- `TimeLabel` - Describes a particular time-located event during the experiment. Any specific aspect of the experiment that you want to document : temperature|light|sound|image on the screen|drug|behaviour ... etc.

- `Labels` - Describes a particular group of time labels.

- `Cycle` - Information about the repeated cycle of labels. Use it when you have some periodic conditions, like : light on , light off, light on, light off... will be made of list of labels [light_on, light_off] that repeat ...

- `Timeline` - Information about the sequence of labels. Use it when you have non-periodic conditions.

- `FrameManager` - Deals with frames. Which frames correspond to a volume / cycle/ condition.

- `VolumeManager` - Figures out how to get full volumes for certain time points.

- `Annotation` - Time annotation of the experiment.

- `Experiment` - Information about the experiment. Will use all the information you provided to figure out what frames to give you based on your request.

# vodex.dbmethods module

#### Keyboard Shortcuts

Keys | Action
--- | ---
`?` | Open this help
`n` | Next page
`p` | Previous page
`s` | Search